Convenience function to download enrollment data for multiple years at once.
Examples
if (FALSE) { # \dontrun{
# Get 2024 and 2025 data
enr_multi <- fetch_enr_multi(c(2024, 2025))
} # }
Convenience function to download enrollment data for multiple years at once.
if (FALSE) { # \dontrun{
# Get 2024 and 2025 data
enr_multi <- fetch_enr_multi(c(2024, 2025))
} # }