Skip to contents

Returns a vector of years for which graduation rate data is available from the California Department of Education.

Usage

get_available_grad_years()

Value

Integer vector of years (2018-2025)

Examples

if (FALSE) { # \dontrun{
get_available_grad_years()
# Returns: 2018 2019 2022 2024 2025
} # }