Adds boolean flags to identify state, county, district, and school level records based on CDS code patterns or the agg_level column.
Adds boolean flags to identify state, county, district, and school level records based on CDS code patterns or the agg_level column.